@@ -7,9 +7,12 @@
 
 import os
 from dotenv import load_dotenv
+from protocol_helper.Exceptions import NotSetDirectory
 
 LOAD_PROJECT_PATH = os.environ.get('LOAD_PROJECT_PATH')
-
+print(LOAD_PROJECT_PATH)
+if LOAD_PROJECT_PATH is None:
+    raise NotSetDirectory
 try:
     load_dotenv(os.path.join(LOAD_PROJECT_PATH, '.env'), encoding = 'gbk')
 except UnicodeDecodeError as error:
